# Copyright (C) 2009    Graham Binns <graham@grahambinns.com>
#
# This file is part of the Frabjous blog and site engine.
#
# Frabjous is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Frabjous is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
# License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Frabjous. If not, see <http://www.gnu.org/licenses/>.
"""Admin module for the Frabjous blog application."""

from django import forms
from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from frabjous.blog.models import Post, PostByEmailAlias


class PostAdminForm(forms.ModelForm):
    """A replacement `ModelForm` for the `Post` class."""
    categories = forms.fields.CharField()

    class Meta:
        model = Post


class PostByEmailAliasAdmin(admin.ModelAdmin):
    list_display = ('user', 'email')


class PostAdmin(admin.ModelAdmin):
    date_hierarchy = 'date_posted'

    fieldsets = (
        (None, {
            'fields': (
                'subject',
                'body',
                'categories',
                'sites',
                'published',
                'comments_enabled',
                'author',
                ),
            }),
        ('Media', {
            'classes': ('collapse',),
            'fields': ('media_objects', 'default_enclosure')
            }),
        ('Advanced', {
            'classes': ('collapse',),
            'fields': (
                'date_posted',
                'slug',
                'license',
                'date_published',
                'excerpt',
                )
            }),
        )
    list_display = (
        'published',
        'date_posted',
        'subject',
        'author',
        )
    list_display_links = (
        'date_posted',
        'subject',
        )
    list_filter = (
        'date_posted',
        'published',
        'categories',
        )
    prepopulated_fields = {'slug': ("subject",)}
    filter_horizontal = ('categories', 'media_objects')

admin.site.register(PostByEmailAlias, PostByEmailAliasAdmin)
admin.site.register(Post, PostAdmin)

