# Copyright (C) 2009    Graham Binns <graham@grahambinns.com>
#
# This file is part of the Frabjous blog and site engine.
#
# Frabjous is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Frabjous is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
# License for more details.
#
# You should have received a copy of the GNU General Public
# License along with Frabjous. If not, see
# <http://www.gnu.org/licenses/>.

from django.conf.urls.defaults import *
from django.views.generic.list_detail import object_list

from frabjous.blog.models import Post
from frabjous.blog.views import category_posts, single_post_by_id
from frabjous.blog.feeds import *


# The feeds what we offer
feeds = {
    'rss':  RSSLatestEntries,
    'atom': AtomLatestEntries,
    'category': CategoryPostFeed,
    'categories': CategoryPostFeed,
    'notcategory': ExcludeCategoryPostFeed,
}


# Extra items for the admin menu.
admin_menu = [
    {'url': '/admin/blog/post/add/', 'text': 'New post',},
    {'url': '/admin/comments/comment/?is_authorised__exact=0',
     'text': 'Moderate comments',},
    ]


urlpatterns = patterns('',
    (r'^(categories|category)/(?P<category>.+)/page/(?P<page>\d+)/$',
        category_posts,),
    (r'^(categories|category)/(?P<category>.+)/$', category_posts,),

    # Anything that starts with four digits is an archive link by year or
    # whatever, so we pass the buck
    (r'^(?P<year>\d{4})/', include('frabjous.blog.urls.archives'),),

    # Anything in the form /post/<id> is a direct link to a Post. We
    # have a special view for that instance.
    (r'^post/(?P<post_id>\d+)/', single_post_by_id),

    (r'^feeds/(?P<url>.*)/$', 'django.contrib.syndication.views.feed',
        {'feed_dict': feeds},),
    (r'^page/(?P<page>\d+)/$',
        object_list,
        dict(queryset=Post.objects.filter(published=True),
            paginate_by=5,
            template_name='blog/postlist.html',)),
    (r'^$',
        object_list,
        dict(
            queryset=Post.objects.get_displayable_posts(),
            paginate_by=5,
            template_name='blog/postlist.html',
            extra_context={'admin_menu': admin_menu})),
)
