# Copyright (C) 2009    Graham Binns <graham@grahambinns.com>
#
# This file is part of the Frabjous blog and site engine.
#
# Frabjous is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Frabjous is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
# License for more details.
#
# You should have received a copy of the GNU General Public
# License along with Frabjous. If not, see
# <http://www.gnu.org/licenses/>.

from django.conf.urls.defaults import *
from django.views.generic.date_based import (
    archive_day, archive_month, archive_year)

from frabjous.blog.models import Post
from frabjous.blog.views import add_comment, single_post
from frabjous.blog.urls import admin_menu


info_dict = {
    'queryset': Post.objects.get_displayable_posts(),
    'date_field': 'date_posted',
}


urlpatterns = patterns('',
    # YYYY/MM/DD/slug/comments/add/ is used for adding comments.
    (r'^(?P<month>\d{2})/(?P<day>\d{2})/(?P<slug>[-\w]+)/comments/add/$',
     add_comment,
    ),
    # YYYY/MM/DD/slug/ should give us an individual post
    (r'^(?P<month>\d{2})/(?P<day>\d{2})/(?P<slug>[-\w]+)/$',
     single_post,
     dict(info_dict,
          slug_field='slug',
          template_name='blog/post.html',
          month_format='%m',
          day_format='%d',
          extra_context={'admin_menu': admin_menu}),
    ),
    # YYYY/MM/DD/ is a day index
    (r'^(?P<month>\d{2})/(?P<day>\d{2})/$',
     archive_day,
     dict(info_dict,
          template_name='blog/postlist.html',
          month_format='%m',
          day_format='%d',
          extra_context={'admin_menu': admin_menu}),
    ),
    # YYYY/MM/DD/ is a month index
    (r'^(?P<month>\d{2})/$',
     archive_month,
     dict(info_dict,
          template_name='blog/postlist.html',
          month_format='%m',
          extra_context={'admin_menu': admin_menu}),
    ),
    # YYYY/ is a year index
    (r'',
     archive_year,
     dict(info_dict,
          template_name='blog/postlist.html',
          make_object_list=True,
          extra_context={'admin_menu': admin_menu}),
    ),
)

