# Copyright (C) 2009    Graham Binns <graham@grahambinns.com>
#
# This file is part of the Frabjous blog and site engine.
#
# Frabjous is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Frabjous is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
# License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Frabjous. If not, see <http://www.gnu.org/licenses/>.
"""Admin classes for the comments app."""

from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from frabjous.comments.models import Comment


class CommentAdmin(admin.ModelAdmin):
    """Admin class for the Comment model."""
    date_hierarchy = 'date'
    fieldsets = (
        (None, {'fields': (
            'content_type', 'object_id', 'in_reply_to', 'user')}),
        ('Content', {'fields': (
            'author_name', 'author_email', 'author_openid', 'body')}),
        ('Meta', {'fields': (
            'date', 'author_ip', 'is_visible', 'is_authorised', 'is_spam')}))
    list_display = (
        'author_name', 'date', 'content_type', 'content_object',
        'is_visible', 'is_authorised', 'is_spam')
    list_display_links = ('author_name', 'date')
    list_filter = ('date', 'is_visible', 'is_authorised', 'is_spam')
    search_fieldsets = ('comment', 'author_name')

admin.site.register(Comment, CommentAdmin)

