# Copyright (C) 2009    Graham Binns <graham@grahambinns.com>
#
# This file is part of the Frabjous blog and site engine.
#
# Frabjous is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Frabjous is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
# License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Frabjous. If not, see <http://www.gnu.org/licenses/>.
"""Forms for the comments app."""

from django import forms

from frabjous.comments.models import Comment


def build_comment_form(request):
    """Build a comment form for the current request."""
    # If we have openid data in the request, use that.
    openids = request.session.get('openids', None)
    if openids is not None:
        # Urgh.
        openid = openids[-1]
        initial_data = {
            'author_name': openid.sreg.get('nickname', ''),
            'author_email': openid.sreg.get('email', ''),
            }
    # If the user is authenticated, use their details.
    elif request.user.is_authenticated():
        initial_data = {
            'author_name': request.user.get_full_name(),
            'author_email': request.user.email,
            }
    else:
        initial_data = {}

    comment_form = CommentForm(initial=initial_data)
    return comment_form


class CommentForm(forms.Form):
    """A form for entering comments on a content object."""

    author_email = forms.CharField(label="Your email address")
    author_name = forms.CharField(label="Your name")
    body = forms.CharField(label="Your comment")
    title = forms.CharField(label="Subject", required=False)
    in_reply_to = forms.IntegerField(required=False)

