# Copyright (C) 2009    Graham Binns <graham@grahambinns.com>
#
# This file is part of the Frabjous blog and site engine.
#
# Frabjous is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# Frabjous is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License
# along with Frabjous. If not, see <http://www.gnu.org/licenses/>.
"""Utils for the comments app."""

from django.conf import settings

def akismet_comment_check(comment):
    """Check with Akismet to see whether `comment` is spam.

    :param comment: A frabjous.comments.models.Comment instance.
    """
    # If Akismet isn't installed, return True - we just assume that
    # everything is spam.
    try:
        from akismet.akismet import Akismet
    except ImportError:
        return True

    akismet = Akismet(
        key=settings.AKISMET_KEY,
        blog_url=settings.AKISMET_BLOG_URL,
        agent='frabjous')

    # Check that the akismet key is valid.
    if not akismet.verify_key():
        # We can't akismetify, so it's spam.
        return True
    else:
        akisment_data = {
            'comment_author': comment.author_name,
            'comment_author_email': comment.author_email,
            'comment_author_url': comment.author_url,
            'user_agent': 'unknown',
            'user_ip': comment.author_ip,
            }
        return akismet.comment_check(
            comment=comment.body, data=akisment_data)
