# Copyright (C) 2010 Graham Binns <graham@grahambinns.com>
#
# This file is part of the Frabjous blog and site engine.
#
# Frabjous is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Frabjous is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
# License for more details.
#
# You should have received a copy of the GNU General Public
# License along with Frabjous. If not, see
# <http://www.gnu.org/licenses/>.
"""Tests for the Links app."""

from django.test import TestCase

from frabjous.links.models import LinkSet


class LinkSetTestCase(TestCase):

    def test_getitem(self):
        # LinkSetManager.__getitem__ acts as a proxy for .get(), using
        # the LinkSet's slug as a key.
        for link_set in LinkSet.objects.all():
            link_set_from_getitem = LinkSet.objects[link_set.slug]
            self.assertEqual(
                link_set, link_set_from_getitem,
                "__getitem__ didn't return the expected LinkSet. "
                "Expected '%s', got '%s'." % (
                    link_set, link_set_from_getitem))

        # __getitem__ raises an error if the LinkSet doesn't exist.
        get_nonexistant_linkset = lambda slug: LinkSet.objects['spoons']
        self.assertRaises(
            LinkSet.DoesNotExist, get_nonexistant_linkset,
            "Expected a DoesNotExist error for nonexistant LinkSet.")
