# Copyright (C) 2009    Graham Binns <graham@grahambinns.com>
#
# This file is part of the Frabjous blog and site engine.
#
# Frabjous is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Frabjous is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
# License for more details.
#
# You should have received a copy of the GNU General Public
# License along with Frabjous. If not, see
# <http://www.gnu.org/licenses/>.
"""A simple middleware for exposing useful information in a ThreadLocal."""

__all__ = [
    'ThreadLocalsMiddleware',
    'get_current_user',
    ]

try:
    from threading import local
except ImportError:
    from django.utils._threading_local import local

thread_locals = local()
def get_current_user():
    return getattr(_thread_locals, 'user', None)

class ThreadLocalsMiddleware(object):
    """Middleware that saves relevant request data in a thread local."""

    def process_request(self, request):
        thread_locals.user = getattr(request, 'user', None)
