# Copyright (C) 2009    Graham Binns <graham@grahambinns.com>
#
# This file is part of the Frabjous blog and site engine.
#
# Frabjous is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Frabjous is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
# License for more details.
#
# You should have received a copy of the GNU General Public
# License along with Frabjous. If not, see
# <http://www.gnu.org/licenses/>.

"""Context processors for the remotefeeds app"""
from django.core.cache import cache

from frabjous.remotefeeds.models import RemoteFeed, FeedPost


def latest_posts(request):
    """Return the latest posts for the blog"""
    latest = cache.get('remotefeeds.RemoteFeed.recent_posts', False)
    if not latest:
        latest = FeedPost.objects.get_recent()
        cache.set('remotefeeds.RemoteFeed.recent_posts', latest)
    return {'feeds': latest,}


def feed_list(request):
    """Return list of registered remote feeds"""
    all = cache.get('remotefeeds.RemoteFeed.all', False)
    if not all:
        all = {}
        for feed in RemoteFeed.objects.all():
            all[feed.name] = feed

        cache.set('remotefeeds.RemoteFeed.all', all)

    return {'feedlist': all,}

