# Copyright (C) 2009    Graham Binns <graham@grahambinns.com>
#
# This file is part of the Frabjous blog and site engine.
#
# Frabjous is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Frabjous is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
# License for more details.
#
# You should have received a copy of the GNU General Public
# License along with Frabjous. If not, see
# <http://www.gnu.org/licenses/>.
"""Database models for the RPC app."""

import xmlrpclib

from django.conf import settings
from django.contrib.contenttypes.models import ContentType
from django.db import models


class RPCPingServer(models.Model):
    """Represents an RPC Server that we ping with an update"""
    url = models.URLField(unique=True, verify_exists=False)

    @property
    def server_proxy(self):
        """Return an xmlrpc server proxy to the remote server."""
        try:
            return self._server_proxy
        except AttributeError:
            self._server_proxy = xmlrpclib.ServerProxy(self.url)
            return self._server_proxy

    def ping(self):
        """Ping the server with an update."""
        self.server_proxy.weblogUpdates.ping(
            settings.PINGBACK_TITLE, settings.PINGBACK_SOURCE_URL)

    def __str__(self):
        return self.url


class Pingback(models.Model):
    """Represents a received XML-RPC pingback."""

    content_type = models.ForeignKey(ContentType)
    date_added = models.DateTimeField(auto_now_add=True)
    object_id = models.IntegerField()
    snippet = models.TextField(blank=True, null=True)
    source_uri = models.URLField(verify_exists=True)

    @property
    def content_object(self):
        """Return the content object to which this pingback belongs."""
        try:
            return self.content_type.get_object_for_this_type(
                pk=self.object_id)
        except ObjectDoesNotExist:
            return None
