# Copyright (C) 2009    Graham Binns <graham@grahambinns.com>
#
# This file is part of the Frabjous blog and site engine.
#
# Frabjous is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Frabjous is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
# License for more details.
#
# You should have received a copy of the GNU General Public
# License along with Frabjous. If not, see
# <http://www.gnu.org/licenses/>.

"""RPC utility functions and classes that don't belong anywhere else."""

from django.conf import settings

from frabjous.rpc.models import RPCPingServer


def rpc_ping(instance, **kwargs):
    """Notify rpc pingable hosts that something happened.

    :param instance: The model that is doing the pinging. If the model
        has a pinged urls field, that field will be populated with the
        list of URLS.
    """
    for srv in RPCPingServer.objects.all():
        # If we've pinged the server already, fugeddit.
        try:
            if instance.rpc_server_pinged(srv):
                continue
        # If the check fails we can't guarantee not going into a loop, so we
        # give up
        except:
            return

        srv.ping()

        # Try adding a ping'd server to the instance
        try:
            instance.add_rpc_pinged(srv)
        except:
            pass


def add_pingback_header(response):
    """Add the X-Pingback header to a response.

    The pingback URL to use is taken from settings.PINGBACK_URL. If
    settings.PINGBACK_ENABLED is False, the header will not be added.
    """
    if settings.PINGBACK_ENABLED:
        response._headers['x-pingback'] = (
            'X-Pingback', settings.PINGBACK_URL)

    return response
