# Copyright (C) 2009 Graham Binns <graham@grahambinns.com>
#
# This file is part of the Frabjous blog and site engine.
#
# Frabjous is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# Frabjous is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License
# along with Frabjous. If not, see <http://www.gnu.org/licenses/>.
"""Settings module for a local Frabjous instance."""

# Your key for the Akismet anti-spam service API.
AKISMET_KEY = ''

# The blog URL to be passed to Akismet when authenticating.
AKISMET_BLOG_URL = ''

# Settings for receiving blog posts by email

# The username for your POP3 account
BLOG_POST_POP3_USER = ''

# The password for your POP3 account.
BLOG_POST_POP3_PASS = ''

# The hostname or IP address of the POP3 server.
BLOG_POST_POP3_SERVER = ''

# The port on which to connect to the POP3 server.
BLOG_POST_POP3_PORT = 110

# Whether or not to use TLS encryption when connecting to the POP3
# server.
BLOG_POST_POP3_TLS = True

# The popularity thresholds for styling categories in a tag cloud.
CATEGORY_POPULARITY_THRESHOLDS = {
    100: 'extremely-popular',
    75: 'very-popular',
    50: 'popular',
    25: 'unpopular',
    0: 'loveless',
}

# The email address from which comment notifications are sent.
COMMENT_EMAIL_ADDRESS = (
    "Example.com comment notifications <comments@example.com>")

# The default license to be used for content.
DEFAULT_LICENSE = 1

# Your API key for the Flickr webservice API.
FLICKR_API_KEY = ''

# The notification email sent when a new comment is posted in reply to a
# blog post or other commentable-upon object.
NOTIFICATION_NEW_COMMENT = """
%(author)s has posted a new comment in reply to "%(subject)s".

The comment reads:

%(body)s

You can read and respond to comments at the following URL:
%(url)s
"""

# The notification email sent when a comment is posted in reply to
# another comment.
NOTIFICATION_NEW_REPLY = """
%(author)s has posted a reply to your comment on "%(subject)s".

The comment reads:

%(body)s

You can read and respond to comments at the following URL:
%(url)s
"""

# Whether or not pingbacks are enabled for this site.
PINGBACK_ENABLED = False

# The URL to which pingbacks should be sent.
PINGBACK_URL = ''

# A tuple of (contentype,[field list], {fieldnames}) tuples defining
# which fields to search on for a given model.
SEARCH_MODELS = (
    ('post',
     ('body', 'subject', 'categories__name',),
     {'date_field': 'date_posted',
      'title_field': 'subject',
      'body_field': 'body',}),
    ('comment',
     ('body', 'title',),
     {'date_field': 'date',
      'title_field': 'title',
      'body_field': 'body',}),
)

# Your key for the Technorati webservice API.
TECHNORATI_KEY = ''

# Context processors for templates.
TEMPLATE_CONTEXT_PROCESSORS = (
    'django.core.context_processors.auth',
    'django.core.context_processors.debug',
    'django_openidconsumer.context_processors.openid',
    'frabjous.blog.context_processors.latest_posts',
    'frabjous.categories.context_processors.category_list',
    'frabjous.comments.context_processors.latest_comments',
    'frabjous.remotefeeds.context_processors.feed_list',
    'frabjous.remotefeeds.context_processors.latest_posts',
    'frabjous.licensing.context_processors.default_license',
    'frabjous.links.context_processors.link_sets',
)

XMLRPC_DEBUG = False
