# Copyright (C) 2009    Graham Binns <graham@grahambinns.com>
#
# This file is part of the Frabjous blog and site engine.
#
# Frabjous is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Frabjous is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
# License for more details.
#
# You should have received a copy of the GNU General Public
# License along with Frabjous. If not, see
# <http://www.gnu.org/licenses/>.
"""A script to update category reference counts periodically."""

import logging
import os
import sys

from django.conf import settings

from frabjous.categories.models import Category


def run(args):
    """Update all categories' reference counts."""
    logging.info("Updating category reference counts.")

    for category in Category.objects.all():
        category.update_ref_count()
        logging.info("'%s' => %i." % (category.name, category.ref_count))

    logging.info("Update complete.")


if __name__ == '__main__':
    logging.basicConfig(
        level=logging.DEBUG,
        format='%(asctime)s %(levelname)s %(message)s',
        filename=os.path.join(
            settings.LOGGING_DIR, 'update-cat-ref-counts.log'))

    run(sys.argv[:1])
