# Copyright (C) 2009    Graham Binns <graham@grahambinns.com>
#
# This file is part of the Frabjous blog and site engine.
#
# Frabjous is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Frabjous is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
# License for more details.
#
# You should have received a copy of the GNU General Public
# License along with Frabjous. If not, see
# <http://www.gnu.org/licenses/>.
"""A script to update all the remote feeds with the latest data"""

import logging
import os
import sys

from django.conf import settings

from frabjous.remotefeeds.models import RemoteFeed


def run(args):
    """Update all remote feeds."""
    logging.info("Updating remote feeds")

    for feed in RemoteFeed.objects.all():
        logging.info("Checking " + feed.name)

        if feed.needs_checking:
            logging.info("Updating " + feed.name)
            feed.update()


if __name__ == '__main__':
    logging.basicConfig(
        level=logging.DEBUG,
        format='%(asctime)s %(levelname)s %(message)s',
        filename=os.path.join(
            settings.LOGGING_DIR, 'update-remote-feeds.log'))

    run(sys.argv[:1])
